package com.jz.dmp.modules.controller;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.annotation.MethodCallLogPrint;
import com.jz.common.annotation.SysOperationLogAnnotation;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.bean.DmpDevelopTaskDto;
import com.jz.dmp.modules.controller.bean.DmpDevelopTaskRequest;
import com.jz.dmp.modules.model.DmpDevelopTask;
import com.jz.dmp.modules.service.DmpDevelopTaskService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * 任务开发(DmpDevelopTask)表控制层
 *
 * @author Bellamy
 * @since 2020-12-22 16:37:56
 */
@RestController
@RequestMapping("/dmpDevelopTask")
@Api(tags = "任务开发")
public class DmpDevelopTaskController {
    /**
     * 服务对象
     */
    @Autowired
    private DmpDevelopTaskService dmpDevelopTaskService;
    
    /**列表查询任务开发
	 * @param dmpDevelopTaskRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/findListWithPage")
	@ApiOperation(value = "分頁列表查询任务开发", notes = "分頁列表查询任务开发")
	@SysOperationLogAnnotation(actionType = "列表查询", descrption = "分頁列表查询任务开发", optModular = "任务开发--查询", isProjOpt = true)
	public PageInfoResponse<DmpDevelopTaskDto> findListWithPage(@RequestBody DmpDevelopTaskRequest dmpDevelopTaskRequest, HttpServletRequest httpRequest){
		PageInfoResponse<DmpDevelopTaskDto> pageInfo = new PageInfoResponse<DmpDevelopTaskDto>();
		try {
			pageInfo = dmpDevelopTaskService.findListWithPage(dmpDevelopTaskRequest, httpRequest);
		} catch (Exception e) {
			pageInfo.setMessage("查询失败");
			pageInfo.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return pageInfo;
	}
	
	/**新增开发任务
	 * @param dmpDevelopTaskRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/add")
	@ApiOperation(value = "新增开发任务", notes = "新增开发任务")
	public BaseBeanResponse<DmpDevelopTask> add(@RequestBody DmpDevelopTask dmpDevelopTask, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpDevelopTask> baseBeanResponse = new BaseBeanResponse<DmpDevelopTask>();
		try {
			baseBeanResponse = dmpDevelopTaskService.add(dmpDevelopTask, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增或修改开发任务失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**treeId查询任务开发
	 * @param dmpDevelopTaskRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.GET, value = "/findByTreeId")
	@ApiOperation(value = "treeId查询任务开发", notes = "treeId查询任务开发")
	@ApiImplicitParam(name = "treeId", value = "treeId")
	public BaseBeanResponse<DmpDevelopTaskDto> view(@RequestParam(name = "treeId", required = true ) Integer treeId, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpDevelopTaskDto> baseBeanResponse = new BaseBeanResponse<DmpDevelopTaskDto>();
		try {
			baseBeanResponse = dmpDevelopTaskService.findByTreeId(treeId, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("请求失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**修改任务开发
	 * @param dmpDevelopTaskRequest
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.POST, value = "/edit")
	@ApiOperation(value = "修改任务开发", notes = "修改任务开发")
	public BaseBeanResponse<DmpDevelopTask> edit(@RequestBody DmpDevelopTask dmpDevelopTask, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpDevelopTask> baseBeanResponse = new BaseBeanResponse<DmpDevelopTask>();
		try {
			baseBeanResponse = dmpDevelopTaskService.edit(dmpDevelopTask, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("修改失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**任务流程发布接口
	 * @param dmpDevelopTaskRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowSubmit")
	@ApiOperation(value = "任务流程发布接口", notes = "任务流程发布接口")
	@ApiImplicitParam(name = "treeId", value = "发布任务树主键")
	@MethodCallLogPrint
	public BaseResponse flowSubmit(@RequestParam(value = "treeId", required = true) Long treeId, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		
		try {
			baseResponse = dmpDevelopTaskService.flowSubmit(treeId, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("任务流程发布失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**SHELL/SQL/离线任务发布接口
	 * @param treeId
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/taskPublish")
	@ApiOperation(value = "SHELL/SQL/离线任务发布接口", notes = "SHELL/SQL/离线任务发布接口")
	@ApiImplicitParam(name = "treeId", value = "发布任务树主键")
	public BaseResponse taskPublish(@RequestParam(value = "treeId", required = true) Long treeId, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		
		try {
			baseResponse = dmpDevelopTaskService.taskPublish(treeId, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("SHELL/SQL/离线任务发布失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**任务立即运行接口
	 * @param treeId
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/taskAzkabanRun")
	@ApiOperation(value = "任务立即运行接口", notes = "任务立即运行接口")
	@ApiImplicitParam(name = "treeId", value = "任务树主键")
	public BaseBeanResponse<Integer> taskAzkabanRun(@RequestParam(value = "treeId", required = true) Long treeId, HttpServletRequest httpRequest){
		BaseBeanResponse<Integer> baseBeanResponse = new BaseBeanResponse<Integer>();
		
		try {
			baseBeanResponse = dmpDevelopTaskService.taskAzkabanRun(treeId, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("任务运行失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**任务立即运行停止
	 * @param treeId
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/taskAzkabanStop")
	@ApiOperation(value = "任务立即运行停止接口", notes = "任务立即运行停止接口")
	@ApiImplicitParam(name = "treeId", value = "任务树主键")
	public BaseBeanResponse<String> taskAzkabanStop(@RequestParam(value = "treeId", required = true) Long treeId, HttpServletRequest httpRequest){
		BaseBeanResponse<String> baseBeanResponse = new BaseBeanResponse<String>();
		
		try {
			baseBeanResponse = dmpDevelopTaskService.taskAzkabanStop(treeId, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("任务运行失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**软删除任务开发
	 * @param id
	 * @return
	 */
	@MethodCallLogPrint
	@RequestMapping(method = RequestMethod.GET, value = "/softDeleteByTreeId")
	@ApiOperation(value = "软删除任务开发", notes = "软删除任务开发")
	@ApiImplicitParam(name = "treeId", value = "任务开发主键")
	public BaseResponse softDeleteByTreeId(@RequestParam(name = "treeId", required = true ) Integer treeId, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpDevelopTaskService.softDeleteByTreeId(treeId, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("软删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}

}