package com.jz.dmp.modules.service.impl;

import java.util.Date;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.google.gson.Gson;
import com.jz.common.enums.ModuleLogEnum;
import com.jz.common.utils.StringUtils;
import com.jz.common.utils.web.SessionUtils;
import com.jz.dmp.modules.dao.DmpModuleOperateLogDao;
import com.jz.dmp.modules.model.DmpMember;
import com.jz.dmp.modules.model.DmpModuleOperateLog;
import com.jz.dmp.modules.service.DmpModuleOperateLogService;

@Service
public class DmpModuleOperateLogServiceImpl implements DmpModuleOperateLogService {

    protected final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private DmpModuleOperateLogDao dao;

    @Override
    @Transactional(readOnly = false)
    public void addRecord(DmpModuleOperateLog operateLog, ModuleLogEnum moduleEnum) throws Exception {
        if (null == moduleEnum || null == operateLog || null == operateLog.getPrimaryKey()) {
            throw new Exception("日志记录参数非法");
        }

        DmpMember user = SessionUtils.getSecurityUser();
        if (user != null) { // && user.getId() != null && user.getId() != 0l) {
            operateLog.setModuleKey(moduleEnum.getCode());
            operateLog.setOperateUserId(user.getUserId());
            operateLog.setOperateUserName(user.getUsername());
            operateLog.setOperateTime(new Date());
            dao.insert(operateLog);
        } else {
            throw new Exception("当前未登录！");
        }
    }

    @Override
    public DmpModuleOperateLog getLastOperateLog(Integer primaryKey, ModuleLogEnum moduleLogEnum) throws Exception {
        if (null == primaryKey || null == moduleLogEnum) {
            throw new Exception("参数非法");
        }
        DmpModuleOperateLog operateLog = new DmpModuleOperateLog();
        operateLog.setModuleKey(moduleLogEnum.getCode());
        operateLog.setPrimaryKey(primaryKey);
        return dao.getLastOperateLog(operateLog);
    }

    @Override
    @Transactional(readOnly = false)
    public DmpModuleOperateLog writeSubmitXmlVersion(Integer primaryKey, String xmlContent) throws Exception {
        if (null == primaryKey || StringUtils.isNull(xmlContent)) {
            throw new Exception("参数非法");
        }

        DmpModuleOperateLog operateLog = null;
        String version = "1";
        try {
            // 获取最新版本号以记录
            DmpModuleOperateLog lastLog = this.getLastOperateLog(primaryKey, ModuleLogEnum.VERSION_SYNC_XML);

            if (null != lastLog) {
                if (StringUtils.toTrimString(lastLog.getOperateLog()).equals(StringUtils.toTrimString(xmlContent))) {
                    logger.info("提交的离线同步脚本与上一版本无差异，忽略此版本");
                    return operateLog;
                } else if (StringUtils.hasLength(lastLog.getRemark())) {
                    version = String.valueOf(Integer.parseInt(lastLog.getRemark()) + 1);
                }
            }

            operateLog = new DmpModuleOperateLog();
            operateLog.setPrimaryKey(primaryKey);
            operateLog.setOperateLog(xmlContent);
            operateLog.setRemark(version);
            this.addRecord(operateLog, ModuleLogEnum.VERSION_SYNC_XML);
            logger.info("离线同步脚本新增版本：{}", new Gson().toJson(operateLog));
        } catch (Exception e) {
            logger.error("记录同步xml版本异常，" + e.getMessage(), e);
        }
        return operateLog;
    }

    @Override
    public List<DmpModuleOperateLog> readSubmitXmlVersion(Integer primaryKey) throws Exception {
        if (null == primaryKey) {
            throw new Exception("参数非法");
        }
        // 需考虑查询效率->索引入手
        DmpModuleOperateLog operateLog = new DmpModuleOperateLog();
        operateLog.setPrimaryKey(primaryKey);
        operateLog.setModuleKey(ModuleLogEnum.VERSION_SYNC_XML.getCode());
        operateLog.setOrder("id desc");
        return dao.findList(operateLog);
    }

}
